<?php

switch ($messaggio) {

case "Vedi le prenotazioni":                             $messaggio = "Buchungen anzeigen"; break;
case "presenti dal":                                     $messaggio = "vom"; break;
case "al":                                               $messaggio = "bis"; break;
case "Senza colori":                                     $messaggio = "Farben ausschalten"; break;
case "Con colori":                                       $messaggio = "Farben einschalten"; break;
case "Tabella prenotazioni precedenti al":               $messaggio = "Tabelle mit Buchungen vor dem"; break;
case "Tabella prenotazioni successive al":               $messaggio = "Tabelle mit Buchungen nach dem"; break;
case "Tabella con tutte le prenotazioni":                $messaggio = "Buchungen"; break;
case "Cognome_cliente":                                  $messaggio = "Nachname"; break;
case "Data_iniziale":                                    $messaggio = "Anreisedatum"; break;
case "Data_finale":                                      $messaggio = "Abreisedatum"; break;
case "sett":                                             $messaggio = "W"; break;
case "gio":                                              $messaggio = "Tag"; break;
case "Tariffa_completa":                                 $messaggio = "Gesamtpreis"; break;
case "Caparra":                                          $messaggio = "Anzahlung"; break;
case "Pagato":                                           $messaggio = "bezahlt"; break;
case "Da_pagare":                                        $messaggio = "offen"; break;
case "Pers.":                                            $messaggio = "Personen"; break;
case "Commento":                                         $messaggio = "Kommentar"; break;
case "Costo_uni.":                                       $messaggio = "Aufpreise"; break;
case "Costo_sett.":                                      $messaggio = "w&ouml;ch. Kosten"; break;
case "Costo_gio.":                                       $messaggio = "t&auml;gl. Kosten"; break;
case "Soldi di prenotazioni cancellate":                 $messaggio = "Geld aus gel&ouml;schten Buchungen"; break;
case "TOTALE":                                           $messaggio = "<b>Summe</b>"; break;
case "Trasferito in cassa":                              $messaggio = "In die Kasse &uuml;bertragen"; break;
case "Sei sicuro di voler cancellare la spesa":          $messaggio = "Wollen Sie den Zahlungsausgang wirklich l&ouml;schen?"; break;
case "del valore di":                                    $messaggio = "im Wert von"; break;
case "Sei sicuro di voler cancellare l'entrata":         $messaggio = "Wollen Sie den Zahlungseingang wirklich l&ouml;schen?"; break;
case "SI":                                               $messaggio = "JA"; break;
case "NO":                                               $messaggio = "NEIN"; break;
case "Entrata o spesa":                                  $messaggio = "Zahlungseingang oder Zahlungsausgang"; break;
case "cacellata":                                        $messaggio = "gel&ouml;scht"; break;
case "Costo o spesa già cancellati":                    $messaggio = "Zahlungseingang oder Zahlungsausgang bereits gel&ouml;scht"; break;
case "Tutte le spese del":  			         $messaggio = "Alle Ausgaben aus "; break;
case "nella cassa principale":  		         $messaggio = "(Hauptkasse)"; break;
case "Natura_spesa":                                     $messaggio = "Zahlungsgrund"; break;
case "Importo":                                          $messaggio = "Wert"; break;
case "Inserita_da":                                      $messaggio = "eingetragen_von"; break;
case "Data_di_inserimento":                              $messaggio = "Eintragungsdatum"; break;
case "Cancella":                                         $messaggio = "L&ouml;schen"; break;
case "Tutte le entrate del":  			         $messaggio = "Alle Einnahmen aus"; break;
case "Natura_entrata":                                   $messaggio = "Grund_f&uuml;r_Eingang"; break;
case "cancella":                                         $messaggio = "l&ouml;schen"; break;
case "entrata presa dalle prenotazioni":                 $messaggio = "Eingang von den Reservierungen abziehen"; break;
case "Inserisci nuove spese o entrate":                  $messaggio = "Neue Eing&auml;nge oder Ausg&auml;nge eingeben"; break;
case "Storia entrate-uscite prenotazioni":               $messaggio = "Verlauf der Reservierungszahlungen"; break;
case "Sei sicuro di voler cancellare il costo aggiuntivo":        $messaggio = "Zuschl&auml;ge wirklich l&ouml;schen?"; break;
case "Il costo aggiuntivo":                              $messaggio = "Die Zuschl&auml;ge"; break;
case "Il costo aggiuntivo è cambiato nel frattempo, non è stato cancellato":        $messaggio = "Die Extrageb&uuml;hren wurden ge&auml;ndert NICHT gel&ouml;scht"; break;
case "è stato cancellato":                              $messaggio = "wurden gel&ouml;scht"; break;
case "I periodi sono stati aggiunti fino al":            $messaggio = "Zeitr&auml;ume wurden hinzugef&uuml;gt bis"; break;
case "Tabella con periodi e relative tariffe del":       $messaggio = "Tarif&uuml;bersicht f&uuml;r"; break;
case "tariffa":                                          $messaggio = "Tarif Nr. "; break;
case "Inizio_settimana":                                 $messaggio = "Wochenanfang"; break;
case "Inizio_giorno":                                    $messaggio = "Starttag"; break;
case "Fine_settimana":                                   $messaggio = "Wochenende"; break;
case "Fine_giorno":                                      $messaggio = "Endtag"; break;
case "Aggiungi periodi":                                 $messaggio = "Zeitr&auml;ume hinzuf&uuml;gen"; break;
case "fino al mese":                                     $messaggio = "bis Monat"; break;
case "Tabella con i costi aggiuntivi del":               $messaggio = "Zuschl&auml;ge f&uumlr"; break;
case "Tipo":                                             $messaggio = "Art"; break;
case "Prezzo":                                           $messaggio = "Wert"; break;
case "Da_assegnare":                                     $messaggio = "verbinden_mit"; break;
case "finale":                                           $messaggio = "einmalig"; break;
case "Sempre":                                           $messaggio = "Immer"; break;
case "Su_richiesta":                                     $messaggio = "auf_Anforderung"; break;
case "chidere_per_quanto_moltiplicare":                  $messaggio = "frage_wie_oft_multipliziert_werden_soll"; break;
case "cosiderare_come_letti_aggiuntivi":                 $messaggio = "als_Zusatzbett_ansehen"; break;
case "settimanale":                                      $messaggio = "w&ouml;chentlich"; break;
case "giornaliero":                                      $messaggio = "t&auml;glich"; break;
case "tutte":                                            $messaggio = "jede"; break;
case "tutti":                                            $messaggio = "jeder"; break;
case "_le":                                              $messaggio = "_der"; break;
case "_i":                                               $messaggio = "_die"; break;
case "_settimane":                                       $messaggio = "_Wochen"; break;
case "_giorni":                                          $messaggio = "_Tage"; break;
case "_meno_una":                                        $messaggio = "_weniger_einem"; break;
case "con_n°_di_settimane":                             $messaggio = "frage_nach_der_Anzahl der Wochen"; break;
case "con_n°_di_giorni":                                $messaggio = "frage_nach_der_Anzahl der Tage"; break;
case "_da_chiedere":                                     $messaggio = "..."; break;
case "percentuale":                                      $messaggio = "Prozentsatz"; break;
case "% arrotondato_a_":                                 $messaggio = "% gerundet_auf_"; break;
case "Caparre, commissioni e tasse del":                 $messaggio = "Anzahlung-, Rabatt- und Steuers&auml;tze f&uuml;r"; break;
case "Arrotondato_a":                                    $messaggio = "gerundet auf"; break;
case "Vai alla pagina di inserzione prezzi":             $messaggio = "Zur Preiseingabeseite"; break;
case "chiamati":                                         $messaggio = "mit Vornamen"; break;
case "Cerca i clienti con cognome o email":              $messaggio = "Suche nach Vorname oder eMail"; break;
case "Tabella con tutti i clienti":                      $messaggio = "G&auml;ste"; break;
case "pag. prec.":                                       $messaggio = "zur&uuml;ck"; break;
case "pag. succ.":                                       $messaggio = "weiter"; break;
case "Cognome":                                          $messaggio = "Nachname"; break;
case "Telefono":                                         $messaggio = "Telefon"; break;
case "Indirizzo":                                        $messaggio = "Addresse"; break;
case "Città":                                           $messaggio = "Stadt"; break;
case "Nazione":                                          $messaggio = "Staatsangeh&ouml;rigkeit"; break;
case "CAP":                                              $messaggio = "Postleitzahl"; break;
case "Fax":                                              $messaggio = "Fax"; break;
case "Email":                                            $messaggio = "E-Mail"; break;
case "Data_di_nascita":                                  $messaggio = "Geburtstag"; break;
case "2°telefono":                                      $messaggio = "2. Telefon"; break;
case "Commento":                                         $messaggio = "Kommentar"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 2 per la":        $messaggio = "Zuweisung Regel 2 wirklich <b>l&ouml;schen</b> f&uuml;r"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":        $messaggio = "Sind sie sicher, da&szlig; Sie die Zuweisungsregel 3 <b>l&ouml;schen</b> wollen f&uuml;r"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":        $messaggio = "Wollen Sie wirklich die <b>Regel Nr. 4 l&ouml;schen</b> "; break;
case "La regola di assegnazione è stata cancellata":    $messaggio = "Zuweisungsregel gel&ouml;scht"; break;
case "La regola di assegnazione è già stata cancellata":        $messaggio = "Die Zuweisungsregel wurde bereits gel&ouml;scht"; break;
case "Tabella con le regole di assegnazione 1 del":      $messaggio = "Regel 1. Fragen bei Zuteilung"; break;
case "Motivazione":                                      $messaggio = "Grund"; break;
case "Tabella con le regole di assegnazione 2 del":      $messaggio = "Regel 2. Tarif->Apartment"; break;
case "Tariffa":                                          $messaggio = "Tarif"; break;
case "Inserisci nuove regole":                           $messaggio = "Neue Regeln eingeben"; break;
case "Il numero inserito esiste già":                   $messaggio = "Die eingegebene Nummer existiert bereits"; break;
case "Continua":                                         $messaggio = "Weiter"; break;
case "Torna indietro":                                   $messaggio = "Zur&uuml;ck"; break;
case "Casa":                                             $messaggio = "Haus"; break;
case "Piano":                                            $messaggio = "Flur"; break;
case "Capienza_massima":                                 $messaggio = "Maximale_Kapazit&auml;t"; break;
case "Priorità":                                        $messaggio = "Priorit&auml;t"; break;
case "Modifica":                                         $messaggio = "Aktion"; break;     //Tabellenberschrift fr Modifikation case "modifica":                                         $messaggio = "&auml;ndern"; break;
case "modifica":                                         $messaggio = "&auml;ndern"; break;
case "Torna al menù principale":                        $messaggio = "Hauptmen&uuml;"; break;
case "persone":                                          $messaggio = "Personen"; break;
case "s":                                                $messaggio = "w"; break;
case "g":                                                $messaggio = "Tag"; break;
case "Mostra":                                           $messaggio = "Anzeigen"; break;
case "Non_mostrare":                                     $messaggio = "nicht_anzeigen"; break;
case "Regole":                                           $messaggio = "Regeln"; break;
case "Tariffe abbinate":                                 $messaggio = "verkn&uuml;pfte_Preise"; break;
case "pagine":                                           $messaggio = "Seiten"; break;
case "Verranno effettuati i seguenti cambiamenti":       $messaggio = "Sie werden diese &Auml;nderungen vornehmen"; break;
case "I soldi pagati per la prenotazione":               $messaggio = "Betrag der f&uuml;r die Reservierung bezahlt wurde"; break;
case "a nome di":                                        $messaggio = "f&uuml;r Herr/Frau"; break;
case "verranno cambiati da":                             $messaggio = "wird ge&auml;ndert von"; break;
case "a":                                                $messaggio = "zu"; break;
case "saldo":                                            $messaggio = "Differenz"; break;
case "Le prenotazioni <b>non sono state modificate</b> perchè sono cambiate nel frattempo":        $messaggio = "Die Reservierungen <b>wurden nicht ge&auml;ndert</b> weil die Reservierungstabelle inzwischen ge&auml;ndert wurde."; break;
case "porre per le prenotazioni selezionate":            $messaggio = "ausgew&auml;hlte Belege in"; break;
case "cambia":                                           $messaggio = "&auml;ndern"; break;
case "tutto pagato":                                     $messaggio = "alles bezahlt"; break;
case "caparra pagata":                                   $messaggio = "Anzahlung bezahlt"; break;
case "pagato niente":                                    $messaggio = "unbezahlt"; break;
case "pagina":                                           $messaggio = "Seite"; break;
case "di":                                               $messaggio = "von"; break;
case "la conferma":                                      $messaggio = "best&auml;tigt"; break;
case "La prenotazione":                                  $messaggio = "Die Reservierung"; break;
case "verrà confermata":                                $messaggio = "wird best&auml;tigt"; break;
case "Data di inserimento":                              $messaggio = "Eingabedatum"; break;
case "Calcola il subtotale delle prenotazioni selezionate":        $messaggio = "Zwischensumme der ausgew&auml;hlten Buchungen berechnen"; break;
case "selezionate precedentemente":                      $messaggio = "wie ausgew&auml;hlt"; break;
case "Saldo totale":                                     $messaggio = "Differenz gesamt"; break;
case "l'anno":                                           $messaggio = "Jahr"; break;
case "dal database":                                     $messaggio = "aus der Datenbank"; break;
case "verranno <b>cancellati</b>":                       $messaggio = "<b>gel&ouml;scht</b>"; break;
case "L'anno":                                           $messaggio = "Jahr"; break;
case "è stato cancellato dal batabase":                 $messaggio = "wurde aus der Datenbank gel&ouml;scht"; break;
case "Non è stato possibile cancellare l'anno":         $messaggio = "L&ouml;schen fehlgeschlagen von Jahr"; break;
case "dal database, controllare i permessi sulla cartella dati":        $messaggio = "aus der Datenbank. Bitte &uuml;berpr&uuml;fen Sie die Rechte des \"dati\" Ordners"; break;
case "Profilo":                                          $messaggio = "Benutzer"; break;
case "Cliente":                                          $messaggio = "Kunde"; break;
case "cliente":                                          $messaggio = "Kunde"; break;
case "Tabella con le regole di assegnazione 3 del":      $messaggio = "Regel 3. Admin->Benutzer"; break;
case "Utente":                                           $messaggio = "Benutzer"; break;
case "Periodi_permessi":                                 $messaggio = "zugewiesene_Zeitr&auml;ume"; break;
case "unico":                                            $messaggio = "einmalig"; break;
case "fisso":                                            $messaggio = "fest"; break;
case "percentuale su tariffa":                           $messaggio = "Prozentsatz des Preises"; break;
case "percentuale su totale":                            $messaggio = "Prozentsatz des Gesamtpreises"; break;
case "varia_con_la_prenotazione":                        $messaggio = "ndert_sich_mit_Reservierung"; break;
case "non_varia_con_la_prenotazione":                    $messaggio = "ndert_sich_nicht_mit_Reservierung"; break;
case "_meno_l'ultima":                                   $messaggio = "_auer_der_letzten"; break;
case "_meno_l'ultimo":                                   $messaggio = "_auer_dem_letzten"; break;
case "_meno_la_prima":                                   $messaggio = "_auer_der_ersten"; break;
case "_meno_il_primo":                                   $messaggio = "_auer_dem_letzten"; break;
case "giorni":                                           $messaggio = "Tage"; break;
case "moltiplicare_per_persone":                         $messaggio = "multiplizieren_mit_Personenanzahl"; break;
case "moltiplicare_per_persone_totali":                  $messaggio = "multiplizieren_mit_Gesamtpersonenzahl"; break;
case "moltiplicare_per_1":                               $messaggio = "multiplizieren_mit_1"; break;
case "massimo_":                                         $messaggio = "maximal_"; break;
case "_nella_stessa_settimana":                          $messaggio = "_in_der_gleichen_Woche"; break;
case "_nello_stesso_giorno":                             $messaggio = "_am_gleichen_Tag"; break;
case "Prenotazione intera in":                           $messaggio = "Gesamte Reservierung"; break;
case "Parte della prentoazione in":                      $messaggio = "Teil der Resrvierung in"; break;
case " o ":                                              $messaggio = " oder "; break;
case " a ":                                              $messaggio = " bis "; break;
case "_si":                                              $messaggio = "_ja"; break;
case "_no":                                              $messaggio = "_nein"; break;
case "_e_":                                              $messaggio = "_und_"; break;
case "associato_a_settimane_specifiche":                 $messaggio = "zugewiesen zu bestimmten Wochen"; break;
case "non_associato_a_settimane_specifiche":             $messaggio = "nicht_verbunden_mit_spezifizierten_Wochen"; break;
case "associato_a_giorni_specifici":                     $messaggio = "zugewiesen zu bestimmten Tagen"; break;
case "non_associato_a_giorni_specifici":                 $messaggio = "nicht_verbunden_mit_spezifizierten_Tagen"; break;
case "modifica con prenotazione":                        $messaggio = "mit der Reservierung ver&auml;ndern"; break;
case "percentuale su caparra":                           $messaggio = "Prozentsatz der Anzahlung"; break;
case "percentuale su resto caparra":                     $messaggio = "Prozentsatz der Anzahlungsdifferenz"; break;
case "Cancellati":                                       $messaggio = "Gel&ouml;scht"; break;
case "clienti":                                          $messaggio = "G&auml;ste"; break;
case "OK":                                               $messaggio = "OK"; break;
case "Annulla":                                          $messaggio = "Abbrechen"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>cancellare":        $messaggio = "Wollen Sie wirklich <div style=\"display: inline; color: red;\"><b>l&ouml;schen"; break;
case "clienti</b></div> che non sono associati a nessuna prenotazione e nessun pagamento":        $messaggio = "Kunden</b></div> ohne zugeordnete Reservierung oder Zahlung"; break;
case "Cancella i clienti senza prenotazioni":            $messaggio = "G&auml;ste ohne Reservierung l&ouml;schen"; break;
case "Metodo pagamento":                                 $messaggio = "Zahlungsweise"; break;
case "Tariffe":                                          $messaggio = "Tarif-Nr."; break;
case "del":                                              $messaggio = "in"; break;
case "Modifica tutti i campi della tabella":             $messaggio = "Direkt&auml;nderung in der Tabelle"; break;
case "Modifica i campi della tabella":                   $messaggio = "Direkt&auml;nderung in der Tabelle"; break;
case "Applica i cambiamenti":                            $messaggio = "&Auml;nderungen &uuml;bernehmen"; break;
case "documento di tipo":                                $messaggio = "Dokumente"; break;
case "visualizza":                                       $messaggio = "erstellen"; break;
case "Vedi tutte le prenotazioni":                       $messaggio = "Alle Reservierungen betrachten"; break;
case "Tabella con le regole di assegnazione 4 del":      $messaggio = "Zuweisung 4. Tarif->G&auml;steanzahl"; break;
case "Numero di persone":                                $messaggio = "Personenanzahl"; break;
case "assegna_se_":                                      $messaggio = "zuweisen_sobald_"; break;
case "più_di_":                                         $messaggio = "weniger_als_"; break;
case "meno_di_":                                         $messaggio = "mehr_als_"; break;
case "_giorni_da_inizio":                                $messaggio = "_Tage_seit_Beginn"; break;
case "assegna_con_":                                     $messaggio = "zuweisen_mit_"; break;
case "_o_più_prenotazioni":                             $messaggio = "_oder_mehr_Reservierungen"; break;
case "Modifica i prezzi":                                $messaggio = "Preise speichern"; break;
case "<div style=\"display: inline; color: red;\">Non</div> è stato possibile inserire alcuni prezzi":        $messaggio = "Einige Preis&auml;nderungen konnten <div style=\"display: inline; color: red;\">nicht</div> erfolgreich durchgef&uuml;hrt werden"; break;
case "I prezzi sono stati aggiornati":                   $messaggio = "Die Preise wurden aktualisiert"; break;
case "Tutte le prenotazioni":                            $messaggio = "Alle Reservierungen"; break;
case "Solo arrivi":                                      $messaggio = "Nur Anreisen"; break;
case "Solo partenze":                                    $messaggio = "Nur Abreisen"; break;
case "dal":                                              $messaggio = "von"; break;
case "Vedi":                                             $messaggio = "ansehen"; break;
case "Tabella con tutti gli arrivi":                     $messaggio = "&uuml;bersicht der Anreisen"; break;
case "Tabella con tutte le partenze":                    $messaggio = "&uuml;bersicht der Abreisen"; break;
case "prova ad importare i prezzi":                      $messaggio = "Preisimport veranlassen"; break;
case "giornalmente":                                     $messaggio = "t&auml;glich"; break;
case "settimanalmente":                                  $messaggio = "w&ouml;chentlich"; break;
case "Origine":                                          $messaggio = "Original"; break;
case "Modifica come gruppo le prenotazioni mostrate in tabella":        $messaggio = "Bearbeitung der ausgew&auml;hlten Buchung"; break;
case "Modifica come gruppo le prenotazioni selezionate": $messaggio = "Stapelbearbeitung der ausgew&auml;hlten Buchungen"; break;
case "Statistiche":                                      $messaggio = "Statistik"; break;
case "Anni":                                             $messaggio = "Jahre"; break;
case "Numero di prenotazioni per mese":                  $messaggio = "Anzahl der Buchungen per Monat"; break;
case "Entrate dalle prenotazioni per mese":              $messaggio = "eingegangene Reservierungen je Monat"; break;
case "Entrate progressive dalle prenotazioni":           $messaggio = "Umsatz aus Reservierungen (kumulativ)"; break;
case "Numero di prenotazioni per origine":               $messaggio = "Anzahl Reservierungen pro Herkunft"; break;
case "Entrate dalle prenotazioni per origine":           $messaggio = "Einkommen von Reservierungen pro Herkunft"; break;
case "Cambia":                                           $messaggio = "&Auml;ndern"; break;
case "Mesi":                                             $messaggio = "Monate"; break;
case "Entrate per metodo di pagamento":                  $messaggio = "Einnahmen je Zahlungsart"; break;
case "Descrizione":                                      $messaggio = "Beschreibung"; break;
case "magazzino":                                        $messaggio = "Lager"; break;
case "inventario":                                       $messaggio = "Bestand"; break;
case "aggiungi":                                         $messaggio = "hinzuf&uuml;gen"; break;
case "Codice":                                           $messaggio = "Art.-Nr"; break;
case "Beni inventario":                                  $messaggio = "Vorr&auml;te"; break;
case "Mancanti":                                         $messaggio = "Fehlbestand"; break;
case "bene eliminato":                                   $messaggio = "Artikel gel&ouml;scht"; break;
case "bene aggiunto":                                    $messaggio = "Artikel zugef&uuml;gt"; break;
case "magazzino eliminato":                              $messaggio = "Lager gel&ouml;scht"; break;
case "magazzino aggiunto":                               $messaggio = "Lager zugef&uuml;gt"; break;
case "Inventario importato":                             $messaggio = "Bestand importiert"; break;
case "Importa l'invetario":                              $messaggio = "Bestand importieren"; break;
case "dal magazzino":                                    $messaggio = "aus Lager"; break;
case "Incompatibilità":                                 $messaggio = "Ausschl&uuml;sse"; break;
case "raggruppa":                                        $messaggio = "Gruppe"; break;
case "con email":                                        $messaggio = "mit eMail:"; break;
case "per persona":                                      $messaggio = "je Person"; break;
case "con meno di":                                      $messaggio = "weniger als"; break;
case "dall'inizio":                                      $messaggio = "von Start"; break;
case "dalla fine":                                       $messaggio = "vom Ende"; break;
case "Mostra solo tariffe selezionate":                  $messaggio = "Nur ausgew&auml;hlte Tarife"; break;
case "mostra prezzi settimanali":                        $messaggio = "w&ouml;chentliche Preise anzeigen"; break;
case "mostra prezzi giornalieri":                        $messaggio = "t&auml;gliche Preise anzeigen"; break;
case "periodi di":                                       $messaggio = "Perioden ab"; break;
case "Valore":                                           $messaggio = "Wert"; break;
case "della tariffa":                                    $messaggio = "Anzahlung"; break;
case "piano":                                            $messaggio = "Etage"; break;
case "casa":                                             $messaggio = "Haus"; break;
case "documento":                                        $messaggio = "Dokument"; break;
case "documenti salvati":                                $messaggio = "gespeicherte Dokumente"; break;
case "in":                                               $messaggio = "in"; break;
case "numero":                                           $messaggio = "Nummer"; break;
case "nome file":                                        $messaggio = "Dateiname"; break;
case "prenotazioni":                                     $messaggio = "Reservierungen"; break;
case "azione":                                           $messaggio = "Aktion"; break;
case "anno":                                             $messaggio = "Jahr"; break;
case "elimina":                                          $messaggio = "l&ouml;schen"; break;
case "fai l'upload del documento numero":                $messaggio = "Dokument Nummer hochladen"; break;
case "fai l'upload":                                     $messaggio = "hochladen"; break;
case "si è sicuri di voler <b class=\"colred\">cancellare</b> il documento":        $messaggio = "Wollen Sie wirklich das gew&auml;hlte Dokument <b class=\"colred\">l&ouml;schen</b>"; break;
case "cancellato":                                       $messaggio = "gel&ouml;scht"; break;
case "inviato":                                          $messaggio = "hochgeladen"; break;
case "Commissioni":                                      $messaggio = "Rabatt"; break;
case "Tasse":                                            $messaggio = "Steuern"; break;
case "senza_commissioni":                                $messaggio = "ohne_Rabatte"; break;
case "Documenti_salvati":                                $messaggio = "gespeicherte_dokumente"; break;
case "TASSE":                                            $messaggio = "Steuern"; break;
case "resto":                                            $messaggio = "offen"; break;
case "cancella_periodi":                                 $messaggio = "gel&ouml;schte_Perioden"; break;
case "sulla tariffa":                                    $messaggio = "Durchschnitt"; break;
case "Le commissioni sono state cancellate":             $messaggio = "Rabatte wurden gel&ouml;scht"; break;
case "Le commissioni sono cambiate nel frattempo, non sono state cancellate":        $messaggio = "Rabatte wurden ge&auml;ndert, nicht gel&ouml;scht"; break;
case "giorno":  				$messaggio = "Tag"; break;
case "settimana":  				$messaggio = "Woche"; break;
case "sconto":  				$messaggio = "Rabatt"; break;
case "Numero di prenotazioni per nazionalità del cliente titolare":	$messaggio = "Anzahl Reservierungen nach Nationalit&auml;t"; break;
case "Entrate dalle prenotazioni per nazionalità del cliente titolare":	$messaggio = "Umsatz aus Reservierungen nach Nationalit&auml;t"; break;
case "Prezzi con":  				$messaggio = "Preise mit"; break;
case "Prenotazioni anno corrente":  		$messaggio = "Reservierungen des aktuellen Jahres"; break;
case "con prenotazioni inserite":  		$messaggio = "Mit Reservierungen"; break;
case "fino al":  				$messaggio = "bis"; break;
case "nella cassa chiamata":  			$messaggio = "in der Kasse"; break;
case "Totale nella cassa principale":  		$messaggio = "Summe in Hauptkasse"; break;
case "Totale nella cassa":  			$messaggio = "Summe in Kasse"; break;
case "Nuova cassa chiamata":  			$messaggio = "Neue Kasse namens"; break;
case "Crea":  					$messaggio = "Anlegen"; break;
case "Una cassa chiamata":  			$messaggio = "Eine Kasse namens"; break;
case "è stata creata":  			$messaggio = "wurde angelegt"; break;
case "Cassa chiamata":  			$messaggio = "Kasse namens"; break;
case "La cassa chiamata":  			$messaggio = "Die Kasse namens"; break;
case "è stata cancellata":  			$messaggio = "wurde gel&ouml;scht"; break;
case "Eventuali entrate e spese presenti in cassa non sono state cancellate":	$messaggio = "Einige Einnahmen und Ausgaben in dieser Kasse wurden nicht gel&ouml;scht"; break;
case "Modifica i beni già inseriti":  		$messaggio = "Bereits eingef&uuml;gte Eintr&auml;ge &auml;ndern"; break;
case "Modifica i beni":  			$messaggio = "Eintrag &auml;ndern"; break;
case "I beni sono stati modificati":  		$messaggio = "Die Eintr&auml;ge wurden ver&auml;ndert"; break;
case "p":  					$messaggio = "p"; break;
case "password errata":  			$messaggio = "falsche Kennwort"; break;
case "Aggiungi":  				$messaggio = "Add"; break;
case "RESTO":  					$messaggio = "REST"; break;
case "Nome":  					$messaggio = "Name"; break;
case "Nome":  					$messaggio = "Name"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 1 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 1 for"; break;
case "<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, tutti i dati riguardanti l'anno":	$messaggio = "<b style=\"color: red;\">WARNING</b>: if you press <b>\"<i>Continue</i>\"</b>, all data regarding year"; break;
case "Solo settimane della prenotazione in":  	$messaggio = "Only weeks of reservation in"; break;
case "Solo giorni della prenotazione in":  	$messaggio = "Only days of reservation in"; break;
case "Importa":  				$messaggio = "Import"; break;
case "Sei sicuro di voler cancellare le commissioni dal":	$messaggio = "Are you sure you want to delete commissions from"; break;
case "costi agg.":  				$messaggio = "extra costs"; break;
case "e combina":  				$messaggio = "and combine"; break;
case "percentuale su fisso della tariffa":	$messaggio = "percentage of fixed rate"; break;
case "percentuale su una persona della tariffa":	$messaggio = "percentage of one person of the rate"; break;
case "non più di":  				$messaggio = "no more than"; break;
case "non più del numero di persone":  		$messaggio = "no more than the number of people"; break;
case "non più del numero totale di persone":  	$messaggio = "no more than the total number of people"; break;
case "meno":  					$messaggio = "minus"; break;
case "aggiungendo":  				$messaggio = "adding"; break;
case "più di":  				$messaggio = "more than"; break;
case "prezzi importati":  			$messaggio = "prices imported"; break;
case "dalla tariffa":  				$messaggio = "from rate"; break;
case "Cancella le carte di credito di prenotazioni passate":	$messaggio = "Delete credit cards of past reservations"; break;
case "password per le carte di credito":  	$messaggio = "password for credit cards"; break;
case "Cancellate":  				$messaggio = "Deleted"; break;
case "carte di credito":  			$messaggio = "credit cards"; break;
case "Creare":  				$messaggio = "Create"; break;
case "persona":  				$messaggio = "person"; break;
case "chiusa":  				$messaggio = "closed"; break;
case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro e nessuna prenotazione non pagata":	$messaggio = "credit cards</b></div> from clients without reservations in the future and without unpaid reservations"; break;
case "presenti in data":  			$messaggio = "present on"; break;
case "comprese partenze":  			$messaggio = "including departures"; break;
case "escludere_da_totale_percentuale":  	$messaggio = "exclude_from_percentage_total"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>